@@ -39,7 +39,6 @@ from .utils import (
     decode_redis_hash,
     ensure_job_list,
     get_call_string,
-    get_version,
     import_attribute,
     now,
     parse_timeout,
@@ -846,12 +845,11 @@ class Job:
 
         from .results import Result
 
-        if self.supports_redis_streams:
-            if not self._cached_result:
-                self._cached_result = self.latest_result()
+        if not self._cached_result:
+            self._cached_result = self.latest_result()
 
-            if self._cached_result and self._cached_result.type == Result.Type.FAILED:
-                return self._cached_result.exc_string
+        if self._cached_result and self._cached_result.type == Result.Type.FAILED:
+            return self._cached_result.exc_string
 
         return self._exc_info
 
@@ -869,17 +867,6 @@ class Job:
         if refresh:
             self._cached_result = None
 
-        if not self.supports_redis_streams:
-            if self._result is not None:
-                return self._result
-
-            rv = self.connection.hget(self.key, 'result')
-            if rv is not None:
-                # cache the result
-                self._result = self.serializer.loads(rv)
-                return self._result
-            return None
-
         if not self._cached_result:
             self._cached_result = self.latest_result()
 
@@ -910,13 +897,13 @@ class Job:
 
         from .results import Result
 
-        if self.supports_redis_streams:
-            if not self._cached_result:
-                self._cached_result = self.latest_result()
+        if not self._cached_result:
+            self._cached_result = self.latest_result()
 
-            if self._cached_result and self._cached_result.type == Result.Type.SUCCESSFUL:
-                return self._cached_result.return_value
+        if self._cached_result and self._cached_result.type == Result.Type.SUCCESSFUL:
+            return self._cached_result.return_value
 
+        # TODO: Remove this fallback in RQ 3.0 - only kept for backward compatibility
         # Fallback to old behavior of getting result from job hash
         if self._result is None:
             rv = self.connection.hget(self.key, 'result')
@@ -1134,6 +1121,7 @@ class Job:
 
         return obj
 
+    # TODO: Remove include_result parameter in RQ 3.0 - results are now always saved to Redis streams
     def save(self, pipeline: Optional['Pipeline'] = None, include_meta: bool = True, include_result: bool = True):
         """Dumps the current job instance to its corresponding Redis key.
 
@@ -1147,6 +1135,7 @@ class Job:
             pipeline (Optional[Pipeline], optional): The Redis' pipeline to use. Defaults to None.
             include_meta (bool, optional): Whether to include the job's metadata. Defaults to True.
             include_result (bool, optional): Whether to include the job's result. Defaults to True.
+                TODO: Remove this parameter in RQ 3.0 - results are now always saved to Redis streams.
         """
         key = self.key
         connection = pipeline if pipeline is not None else self.connection
@@ -1154,22 +1143,6 @@ class Job:
         mapping = self.to_dict(include_meta=include_meta, include_result=include_result)
         connection.hset(key, mapping=mapping)
 
-    @property
-    def supports_redis_streams(self) -> bool:
-        """Only supported by Redis server >= 5.0 is required."""
-        return self.get_redis_server_version() >= (5, 0, 0)
-
-    def get_redis_server_version(self) -> tuple[int, int, int]:
-        """Return Redis server version of connection
-
-        Returns:
-            redis_server_version (Tuple[int, int, int]): The Redis version within a Tuple of integers, eg (5, 0, 9)
-        """
-        if self.redis_server_version is None:
-            self.redis_server_version = get_version(self.connection)
-
-        return self.redis_server_version
-
     def save_meta(self):
         """Stores job meta from the job instance to the corresponding Redis key."""
         meta = self.serializer.dumps(self.meta)
@@ -1534,54 +1507,48 @@ class Job:
             self.log.exception('Job %s: error while executing stopped callback', self.id)
             raise
 
-    def _handle_success(self, result_ttl: int, pipeline: 'Pipeline'):
+    def _handle_success(self, result_ttl, pipeline: 'Pipeline', worker_name: str = ''):
         """Saves and cleanup job after successful execution"""
         self.log.debug('Job %s: handling success...', self.id)
 
         self.set_status(JobStatus.FINISHED, pipeline=pipeline)
-        # Result should be saved in job hash only if server
-        # doesn't support Redis streams
-        include_result = not self.supports_redis_streams
         # Don't clobber user's meta dictionary!
-        self.save(pipeline=pipeline, include_meta=False, include_result=include_result)
-        # Result creation should eventually be moved to job.save() after support
-        # for Redis < 5.0 is dropped. job.save(include_result=...) is used to test
-        # for backward compatibility
-        if self.supports_redis_streams:
-            from .results import Result
+        self.save(pipeline=pipeline, include_meta=False, include_result=False)
+        from .results import Result
 
-            Result.create(self, Result.Type.SUCCESSFUL, return_value=self._result, ttl=result_ttl, pipeline=pipeline)
+        Result.create(
+            self,
+            Result.Type.SUCCESSFUL,
+            return_value=self._result,
+            ttl=result_ttl,
+            worker_name=worker_name,
+            pipeline=pipeline,
+        )
 
         if result_ttl != 0:
             finished_job_registry = self.finished_job_registry
             finished_job_registry.add(self, result_ttl, pipeline)
 
-    def _handle_failure(self, exc_string: str, pipeline: 'Pipeline'):
+    def _handle_failure(self, exc_string: str, pipeline: 'Pipeline', worker_name: str = ''):
         self.log.debug(
             'Job %s: handling failure: %s', self.id, exc_string[:200] + '...' if len(exc_string) > 200 else exc_string
         )
 
         failed_job_registry = self.failed_job_registry
-        # Exception should be saved in job hash if server
-        # doesn't support Redis streams
-        _save_exc_to_job = not self.supports_redis_streams
         failed_job_registry.add(
             self,
             ttl=self.failure_ttl,
             exc_string=exc_string,
             pipeline=pipeline,
-            _save_exc_to_job=_save_exc_to_job,
         )
-        if self.supports_redis_streams:
-            from .results import Result
+        from .results import Result
 
-            Result.create_failure(self, self.failure_ttl, exc_string=exc_string, pipeline=pipeline)
+        Result.create_failure(self, self.failure_ttl, exc_string=exc_string, worker_name=worker_name, pipeline=pipeline)
 
-    def _handle_retry_result(self, queue: 'Queue', pipeline: 'Pipeline'):
-        if self.supports_redis_streams:
-            from .results import Result
+    def _handle_retry_result(self, queue: 'Queue', pipeline: 'Pipeline', worker_name: str = ''):
+        from .results import Result
 
-            Result.create_retried(self, self.failure_ttl, pipeline=pipeline)
+        Result.create_retried(self, self.failure_ttl, worker_name=worker_name, pipeline=pipeline)
         self.number_of_retries = 1 if not self.number_of_retries else self.number_of_retries + 1
         queue._enqueue_job(self, pipeline=pipeline)
 
