@@ -14,7 +14,8 @@ or a direct callable (function/method).
 """
 
 
-JobDependencyType = TypeVar('JobDependencyType', 'Dependency', 'Job', str, list[Union['Dependency', 'Job', str]])
+JobDependencyType = Union['Dependency', 'Job', str, list[Union['Dependency', 'Job', str]]]
+
 """Custom type definition for a job dependencies.
 A simple helper definition for the `depends_on` parameter when creating a job.
 """
